@@ -25,8 +25,8 @@
 #include <config.h>
 
 // Qt
+#include <QDBusContext>
 #include <QString>
-#include <QtDBus/QtDBus> 
 
 #include <qlist.h>
 #include <QTimer>
@@ -53,15 +53,14 @@ KMixD : public KDEDModule, protected QDBusContext
 
   private:
    bool m_multiDriverMode;
-
-   QString m_hwInfoString;
    QList<QString> m_backendFilter;
 
   private slots:
    void delayedInitialization();
    void saveConfig();
-   void plugged( const char* driverName, const QString& udi, QString& dev);
-   void unplugged( const QString& udi);
+
+   void plugged(const char *driverName, const QString &udi, int dev);
+   void unplugged(const QString &udi);
 };
 
 #endif // KMIXD_H
