@@ -136,7 +136,7 @@ int Mixer_MPRIS2::readVolumeFromHW( const QString& /*id*/, shared_ptr<MixDevice>
 void Mixer_MPRIS2::playbackStateChanged(MPrisControl* mad, MediaController::PlayState playState)
 {
 	shared_ptr<MixDevice> md = m_mixDevices.get(mad->getId());
-	md->getMediaController()->setPlayState(playState);
+	md->mediaController()->setPlayState(playState);
 	QMetaObject::invokeMethod(this, "announceGUI", Qt::QueuedConnection);
 //	ControlManager::instance().announce(_mixer->id(), ControlManager::GUI, QString("MixerMPRIS2.playbackStateChanged"));
 }
@@ -236,12 +236,6 @@ unsigned int Mixer_MPRIS2::enumIdHW(const QString&)
 	return 0;
 }
 
-bool Mixer_MPRIS2::moveStream( const QString&, const QString&  )
-{
-	// not supported in MPRIS
-	return false;
-}
-
 
 /**
  * Adds all currently running players and then starts listening
@@ -496,7 +490,7 @@ void Mixer_MPRIS2::watcherPlugControlId(QDBusPendingCallWatcher* watcher)
 		// Thus we won't add the playback switch
 		Volume* vol = new Volume( 100, 0, false, false);
 		vol->addVolumeChannel(VolumeChannel(Volume::LEFT)); // MPRIS is only one control ("Mono")
-		MediaController* mediaContoller = mdNew->getMediaController();
+		MediaController* mediaContoller = mdNew->mediaController();
 		mediaContoller->addMediaPlayControl();
 		mediaContoller->addMediaNextControl();
 		mediaContoller->addMediaPrevControl();
