@@ -296,15 +296,10 @@ unsigned int Mixer::size() const
   return _mixerBackend->m_mixDevices.count();
 }
 
-shared_ptr<MixDevice> Mixer::operator[](int num)
-{
-	shared_ptr<MixDevice> md =  _mixerBackend->m_mixDevices.at( num );
-	return md;
-}
 
-MixSet& Mixer::getMixSet()
+MixSet &Mixer::getMixSet() const
 {
-  return _mixerBackend->m_mixDevices;
+    return (_mixerBackend->m_mixDevices);
 }
 
 
@@ -710,11 +705,17 @@ bool Mixer::isDynamic()
     return m_dynamic;
 }
 
-bool Mixer::moveStream( const QString id, const QString& destId )
+
+bool Mixer::moveStream(const QString &id, const QString &destId)
 {
     // We should really check that id is within our md's....
-    bool ret = _mixerBackend->moveStream( id, destId );
+    bool ret = _mixerBackend->moveStream(id, destId);
     ControlManager::instance().announce(QString(), ControlManager::ControlList, QString("Mixer.moveStream()"));
-    return ret;
+    return (ret);
 }
 
+
+QString Mixer::currentStreamDevice(const QString &id) const
+{
+    return (_mixerBackend->currentStreamDevice(id));
+}
