@@ -26,6 +26,8 @@
 #include <QIcon>
 #include <QPushButton>
 
+#include "core/ControlManager.h"
+
 class QBoxLayout;
 class QFrame;
 class QGridLayout;
@@ -51,8 +53,8 @@ public:
 protected:
     KMixWindow  *_kmixMainWindow;
 
-    void wheelEvent ( QWheelEvent * e ) Q_DECL_OVERRIDE;
-    void _setMixSet() Q_DECL_OVERRIDE;
+    void initLayout() Q_DECL_OVERRIDE;
+    Qt::Orientation orientationSetting() const Q_DECL_OVERRIDE;
 
 private:
   QGridLayout* _layoutMDW;
@@ -75,7 +77,7 @@ private:
     static QString InternedString_Subcontrols;
 
 public slots:
-       void controlsChange(int changeType);
+       void controlsChange(ControlManager::ChangeType changeType);
        void configureView() Q_DECL_OVERRIDE;
 
 private slots:
